@@ -134,7 +134,7 @@ class _FinalWrapper:
             F = np.ones((T.shape[0], 1))
         return cross_product(F, T)
 
-    def fit(self, X, T_res, Y_res, sample_weight=None, sample_var=None):
+    def fit(self, X, T, T_res, Y_res, sample_weight=None, sample_var=None):
         # Track training dimensions to see if Y or T is a vector instead of a 2-dimensional array
         self._d_t = shape(T_res)[1:]
         self._d_y = shape(Y_res)[1:]
